# Changelog

## 1.1.0

- Add `taper: true` for full-length tapers.

## 1.0.15

- Bug fixes related to very short lines.

## 1.0.14

- Updates README and documentation.

## 1.0.13

- Fixes an issue where default values were incorrectly being inserted for zero pressure points.

## 1.0.12

- Fixes cusp at the end of tapered lines.

## 1.0.11

- Adds correct license.

## 1.0.8

- Removes more unused
- Fixes bug when size was negative
- Adds a few thousand tests

## 1.0.8

- Removes unused code
- Improves start and end caps

## 1.0.6

- Fixes appearance of start caps
- Fix appearance of tapered end cap
- Fix issues where points had more than 2 numbers
- Fix flat caps
- Improves streamlining
- Fix a bug with corner caps on straight lines
- Simplifies algorithm

## 1.0.5

- Improves array methods for a very minor improvement in speed and memory performance.
